==> webkit2gtk_2.51.2.orig.tar.xz: webkitgtk-2.51.2/Source/WebCore/platform/graphics/coreimage/FEComponentTransferCoreImageApplier.h <==
/*
 * Copyright (C) 2020-2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if USE(CORE_IMAGE)

#import "FilterEffectApplier.h"
#import <wtf/TZoneMalloc.h>

namespace WebCore {

class FEComponentTransfer;

class FEComponentTransferCoreImageApplier final : public FilterEffectConcreteApplier<FEComponentTransfer> {
    WTF_MAKE_TZONE_ALLOCATED(FEComponentTransferCoreImageApplier);
    using Base = FilterEffectConcreteApplier<FEComponentTransfer>;

public:
    FEComponentTransferCoreImageApplier(const FEComponentTransfer&);

    static bool supportsCoreImageRendering(const FEComponentTransfer&);

private:
    bool apply(const Filter&, std::span<const Ref<FilterImage>> inputs, FilterImage& result) const final;
    bool applyLinear(RetainPtr<CIImage>, FilterImage&) const;
#if HAVE(CI_KERNEL)
    bool applyGamma(RetainPtr<CIImage>, FilterImage&) const;
#endif
};

} // namespace WebCore

#endif // USE(CORE_IMAGE)

==> webkit2gtk_2.51.91.orig.tar.xz: webkitgtk-2.51.91/Source/WebCore/platform/graphics/coreimage/FEComponentTransferCoreImageApplier.h <==
/*
 * Copyright (C) 2020-2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if USE(CORE_IMAGE)

#import "FilterEffectApplier.h"
#import <wtf/TZoneMalloc.h>

namespace WebCore {

class FEComponentTransfer;

class FEComponentTransferCoreImageApplier final : public FilterEffectConcreteApplier<FEComponentTransfer> {
    WTF_MAKE_TZONE_ALLOCATED(FEComponentTransferCoreImageApplier);
    using Base = FilterEffectConcreteApplier<FEComponentTransfer>;

public:
    FEComponentTransferCoreImageApplier(const FEComponentTransfer&);

private:
    bool apply(const Filter&, std::span<const Ref<FilterImage>> inputs, FilterImage& result) const final;
    RetainPtr<CIImage> applyLinear(RetainPtr<CIImage>&&) const;
    RetainPtr<CIImage> applyOther(RetainPtr<CIImage>&&) const;
};

} // namespace WebCore

#endif // USE(CORE_IMAGE)
